@@ -17,7 +17,9 @@
 #include "video.h"
 
 CTVideo::CTVideo(QObject *parent) :
-    QObject(parent)
+    QObject(parent),
+    m_downloadable(true),
+    m_viewCount(0)
 {
 }
 
@@ -25,6 +27,7 @@ CTVideo::CTVideo(const CTVideo *video, QObject *parent) :
     QObject(parent),
     m_date(video->date()),
     m_description(video->description()),
+    m_downloadable(video->isDownloadable()),
     m_duration(video->duration()),
     m_id(video->id()),
     m_largeThumbnailUrl(video->largeThumbnailUrl()),
@@ -83,6 +86,17 @@ void CTVideo::setId(const QString &i) {
     }
 }
 
+bool CTVideo::isDownloadable() const {
+    return m_downloadable;
+}
+
+void CTVideo::setDownloadable(bool d) {
+    if (d != isDownloadable()) {
+        m_downloadable = d;
+        emit downloadableChanged();
+    }
+}
+
 QUrl CTVideo::largeThumbnailUrl() const {
     return m_largeThumbnailUrl;
 }
@@ -189,6 +203,7 @@ void CTVideo::viewed() {
 void CTVideo::loadVideo(CTVideo *video) {
     setDate(video->date());
     setDescription(video->description());
+    setDownloadable(video->isDownloadable()),
     setDuration(video->duration());
     setId(video->id());
     setLargeThumbnailUrl(video->largeThumbnailUrl());
