@@ -25,7 +25,6 @@ class ImageCache;
 class ListView;
 class QLabel;
 class QVBoxLayout;
-class QActionGroup;
 
 class DailymotionPlaylistsWindow : public StackedWindow
 {
@@ -39,9 +38,6 @@ public Q_SLOTS:
     void list(const QString &resourcePath, const QVariantMap &filters = QVariantMap());
     
 private Q_SLOTS:
-    void enableGridMode();
-    void enableListMode();
-    
     void showPlaylist(const QModelIndex &index);
         
     void onImageReady();
@@ -53,9 +49,6 @@ private:
     
     ListView *m_view;
     PlaylistDelegate *m_delegate;
-    QActionGroup *m_viewGroup;
-    QAction *m_listAction;
-    QAction *m_gridAction;
     QAction *m_reloadAction;
     QLabel *m_label;
     QVBoxLayout *m_layout;
