@@ -38,7 +38,6 @@
 #include <qdailymotion/urls.h>
 #include <QScrollArea>
 #include <QLabel>
-#include <QActionGroup>
 #include <QGridLayout>
 #include <QMessageBox>
 #include <QMenuBar>
@@ -64,9 +63,6 @@ DailymotionPlaylistWindow::DailymotionPlaylistWindow(const QString &id, StackedW
     m_userLabel(new QLabel(this)),
     m_noVideosLabel(new QLabel(QString("<p align='center'; style='font-size: 40px; color: %1'>%2</p>")
                                       .arg(palette().color(QPalette::Mid).name()).arg(tr("No videos found")), this)),
-    m_viewGroup(new QActionGroup(this)),
-    m_listAction(new QAction(tr("List"), this)),
-    m_gridAction(new QAction(tr("Grid"), this)),
     m_reloadAction(new QAction(tr("Reload"), this)),
     m_contextMenu(new QMenu(this)),
     m_downloadAction(new QAction(tr("Download"), this)),
@@ -101,9 +97,6 @@ DailymotionPlaylistWindow::DailymotionPlaylistWindow(const DailymotionPlaylist *
     m_userLabel(new QLabel(this)),
     m_noVideosLabel(new QLabel(QString("<p align='center'; style='font-size: 40px; color: %1'>%2</p>")
                                       .arg(palette().color(QPalette::Mid).name()).arg(tr("No videos found")), this)),
-    m_viewGroup(new QActionGroup(this)),
-    m_listAction(new QAction(tr("List"), this)),
-    m_gridAction(new QAction(tr("Grid"), this)),
     m_reloadAction(new QAction(tr("Reload"), this)),
     m_contextMenu(new QMenu(this)),
     m_downloadAction(new QAction(tr("Download"), this)),
@@ -140,16 +133,10 @@ void DailymotionPlaylistWindow::loadBaseUi() {
     m_avatar->setFixedSize(60, 60);
     
     m_titleLabel->setWordWrap(true);
-    m_dateLabel->setStyleSheet(QString("color: %1; font-size: 18px").arg(palette().color(QPalette::Mid).name()));
-    m_userLabel->setStyleSheet("font-size: 18px");
+    m_dateLabel->setStyleSheet(QString("color: %1; font-size: 13pt").arg(palette().color(QPalette::Mid).name()));
+    m_userLabel->setStyleSheet("font-size: 13pt");
     m_noVideosLabel->hide();
-    
-    m_listAction->setCheckable(true);
-    m_listAction->setChecked(true);
-    m_gridAction->setCheckable(true);
-    m_viewGroup->setExclusive(true);
-    m_viewGroup->addAction(m_listAction);
-    m_viewGroup->addAction(m_gridAction);
+
     m_reloadAction->setEnabled(false);
     
     m_contextMenu->addAction(m_downloadAction);
@@ -178,8 +165,6 @@ void DailymotionPlaylistWindow::loadBaseUi() {
     m_layout->setStretch(2, 1);
     m_layout->setContentsMargins(0, 0, 0, 0);
     
-    menuBar()->addAction(m_listAction);
-    menuBar()->addAction(m_gridAction);
     menuBar()->addAction(m_reloadAction);
     
     connect(m_model, SIGNAL(statusChanged(QDailymotion::ResourcesRequest::Status)), this,
@@ -188,8 +173,6 @@ void DailymotionPlaylistWindow::loadBaseUi() {
     connect(m_view, SIGNAL(activated(QModelIndex)), this, SLOT(showVideo(QModelIndex)));
     connect(m_view, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showContextMenu(QPoint)));
     connect(m_delegate, SIGNAL(thumbnailClicked(QModelIndex)), this, SLOT(playVideo(QModelIndex)));
-    connect(m_listAction, SIGNAL(triggered()), this, SLOT(enableListMode()));
-    connect(m_gridAction, SIGNAL(triggered()), this, SLOT(enableGridMode()));
     connect(m_reloadAction, SIGNAL(triggered()), m_model, SLOT(reload()));
     connect(m_avatar, SIGNAL(clicked()), this, SLOT(showUser()));
     connect(m_descriptionLabel, SIGNAL(anchorClicked(QUrl)), this, SLOT(showResource(QUrl)));
@@ -213,10 +196,6 @@ void DailymotionPlaylistWindow::loadBaseUi() {
     if (Settings::instance()->videoPlayer() == "cutetube") {
         connect(m_thumbnail, SIGNAL(clicked()), this, SLOT(playPlaylist()));
     }
-    
-    if (Settings::instance()->defaultViewMode() == "grid") {
-        m_gridAction->trigger();
-    }
 }
 
 void DailymotionPlaylistWindow::loadPlaylistUi() {
@@ -239,20 +218,6 @@ void DailymotionPlaylistWindow::loadUserUi() {
     m_avatar->setSource(m_user->thumbnailUrl());
 }
 
-void DailymotionPlaylistWindow::enableGridMode() {
-    m_delegate->setGridMode(true);
-    m_view->setFlow(QListView::LeftToRight);
-    m_view->setWrapping(true);
-    Settings::instance()->setDefaultViewMode("grid");
-}
-
-void DailymotionPlaylistWindow::enableListMode() {
-    m_delegate->setGridMode(false);
-    m_view->setFlow(QListView::TopToBottom);
-    m_view->setWrapping(false);
-    Settings::instance()->setDefaultViewMode("list");
-}
-
 void DailymotionPlaylistWindow::getVideos() {
     QVariantMap filters;
     filters["limit"] = 50;
