@@ -36,7 +36,6 @@
 #include "videoplaybackwindow.h"
 #include <QScrollArea>
 #include <QLabel>
-#include <QActionGroup>
 #include <QGridLayout>
 #include <QMessageBox>
 #include <QMenuBar>
@@ -62,9 +61,6 @@ PluginPlaylistWindow::PluginPlaylistWindow(const QString &service, const QString
     m_userLabel(new QLabel(this)),
     m_noVideosLabel(new QLabel(QString("<p align='center'; style='font-size: 40px; color: %1'>%2</p>")
                                       .arg(palette().color(QPalette::Mid).name()).arg(tr("No videos found")), this)),
-    m_viewGroup(new QActionGroup(this)),
-    m_listAction(new QAction(tr("List"), this)),
-    m_gridAction(new QAction(tr("Grid"), this)),
     m_reloadAction(new QAction(tr("Reload"), this)),
     m_contextMenu(new QMenu(this)),
     m_downloadAction(new QAction(tr("Download"), this)),
@@ -96,9 +92,6 @@ PluginPlaylistWindow::PluginPlaylistWindow(const PluginPlaylist *playlist, Stack
     m_userLabel(new QLabel(this)),
     m_noVideosLabel(new QLabel(QString("<p align='center'; style='font-size: 40px; color: %1'>%2</p>")
                                       .arg(palette().color(QPalette::Mid).name()).arg(tr("No videos found")), this)),
-    m_viewGroup(new QActionGroup(this)),
-    m_listAction(new QAction(tr("List"), this)),
-    m_gridAction(new QAction(tr("Grid"), this)),
     m_reloadAction(new QAction(tr("Reload"), this)),
     m_contextMenu(new QMenu(this)),
     m_downloadAction(new QAction(tr("Download"), this)),
@@ -134,17 +127,11 @@ void PluginPlaylistWindow::loadBaseUi() {
     m_avatar->hide();
     
     m_titleLabel->setWordWrap(true);
-    m_dateLabel->setStyleSheet(QString("color: %1; font-size: 18px").arg(palette().color(QPalette::Mid).name()));
-    m_userLabel->setStyleSheet("font-size: 18px");
+    m_dateLabel->setStyleSheet(QString("color: %1; font-size: 13pt").arg(palette().color(QPalette::Mid).name()));
+    m_userLabel->setStyleSheet("font-size: 13pt");
     m_userLabel->hide();
     m_noVideosLabel->hide();
-    
-    m_listAction->setCheckable(true);
-    m_listAction->setChecked(true);
-    m_gridAction->setCheckable(true);
-    m_viewGroup->setExclusive(true);
-    m_viewGroup->addAction(m_listAction);
-    m_viewGroup->addAction(m_gridAction);
+
     m_reloadAction->setEnabled(false);
     
     m_contextMenu->addAction(m_downloadAction);
@@ -173,8 +160,6 @@ void PluginPlaylistWindow::loadBaseUi() {
     m_layout->setStretch(2, 1);
     m_layout->setContentsMargins(0, 0, 0, 0);
     
-    menuBar()->addAction(m_listAction);
-    menuBar()->addAction(m_gridAction);
     menuBar()->addAction(m_reloadAction);
     
     connect(m_model, SIGNAL(statusChanged(ResourcesRequest::Status)), this,
@@ -183,8 +168,6 @@ void PluginPlaylistWindow::loadBaseUi() {
     connect(m_view, SIGNAL(activated(QModelIndex)), this, SLOT(showVideo(QModelIndex)));
     connect(m_view, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showContextMenu(QPoint)));
     connect(m_delegate, SIGNAL(thumbnailClicked(QModelIndex)), this, SLOT(playVideo(QModelIndex)));
-    connect(m_listAction, SIGNAL(triggered()), this, SLOT(enableListMode()));
-    connect(m_gridAction, SIGNAL(triggered()), this, SLOT(enableGridMode()));
     connect(m_reloadAction, SIGNAL(triggered()), m_model, SLOT(reload()));
     connect(m_descriptionLabel, SIGNAL(anchorClicked(QUrl)), this, SLOT(showResource(QUrl)));
     connect(m_downloadAction, SIGNAL(triggered()), this, SLOT(downloadVideo()));
@@ -193,10 +176,6 @@ void PluginPlaylistWindow::loadBaseUi() {
     if (Settings::instance()->videoPlayer() == "cutetube") {
         connect(m_thumbnail, SIGNAL(clicked()), this, SLOT(playPlaylist()));
     }
-    
-    if (Settings::instance()->defaultViewMode() == "grid") {
-        m_gridAction->trigger();
-    }
 }
 
 void PluginPlaylistWindow::loadPlaylistUi() {
@@ -215,20 +194,6 @@ void PluginPlaylistWindow::loadUserUi() {
     connect(m_avatar, SIGNAL(clicked()), this, SLOT(showUser()));
 }
 
-void PluginPlaylistWindow::enableGridMode() {
-    m_delegate->setGridMode(true);
-    m_view->setFlow(QListView::LeftToRight);
-    m_view->setWrapping(true);
-    Settings::instance()->setDefaultViewMode("grid");
-}
-
-void PluginPlaylistWindow::enableListMode() {
-    m_delegate->setGridMode(false);
-    m_view->setFlow(QListView::TopToBottom);
-    m_view->setWrapping(false);
-    Settings::instance()->setDefaultViewMode("list");
-}
-
 void PluginPlaylistWindow::getVideos() {
     m_model->setService(m_playlist->service());
     m_model->list(m_playlist->id());
@@ -405,7 +370,7 @@ void PluginPlaylistWindow::onPlaylistStatusChanged(ResourcesRequest::Status stat
     
     hideProgressIndicator();
     disconnect(m_playlist, SIGNAL(statusChanged(ResourcesRequest::Status)),
-               this, SLOT(onUserStatusChanged(ResourcesRequest::Status)));
+               this, SLOT(onPlaylistStatusChanged(ResourcesRequest::Status)));
 }
 
 void PluginPlaylistWindow::onUserStatusChanged(ResourcesRequest::Status status) {
