@@ -26,7 +26,6 @@
 #include "videolauncher.h"
 #include "videoplaybackwindow.h"
 #include <QLabel>
-#include <QActionGroup>
 #include <QMessageBox>
 #include <QVBoxLayout>
 #include <QMenuBar>
@@ -41,9 +40,6 @@ PluginVideosWindow::PluginVideosWindow(StackedWindow *parent) :
     m_delegate(new VideoDelegate(m_cache, PluginVideoModel::DateRole, PluginVideoModel::DurationRole,
                                  PluginVideoModel::ThumbnailUrlRole, PluginVideoModel::TitleRole,
                                  PluginVideoModel::UsernameRole, this)),
-    m_viewGroup(new QActionGroup(this)),
-    m_listAction(new QAction(tr("List"), this)),
-    m_gridAction(new QAction(tr("Grid"), this)),
     m_reloadAction(new QAction(tr("Reload"), this)),
     m_contextMenu(new QMenu(this)),
     m_downloadAction(new QAction(tr("Download"), this)),
@@ -57,13 +53,7 @@ PluginVideosWindow::PluginVideosWindow(StackedWindow *parent) :
     m_view->setModel(m_model);
     m_view->setItemDelegate(m_delegate);
     m_view->setContextMenuPolicy(Qt::CustomContextMenu);
-    
-    m_listAction->setCheckable(true);
-    m_listAction->setChecked(true);
-    m_gridAction->setCheckable(true);
-    m_viewGroup->setExclusive(true);
-    m_viewGroup->addAction(m_listAction);
-    m_viewGroup->addAction(m_gridAction);
+
     m_reloadAction->setEnabled(false);
     
     m_contextMenu->addAction(m_downloadAction);
@@ -76,8 +66,6 @@ PluginVideosWindow::PluginVideosWindow(StackedWindow *parent) :
     m_layout->addWidget(m_label);
     m_layout->setContentsMargins(0, 0, 0, 0);
     
-    menuBar()->addAction(m_listAction);
-    menuBar()->addAction(m_gridAction);
     menuBar()->addAction(m_reloadAction);
     
     connect(m_model, SIGNAL(statusChanged(ResourcesRequest::Status)), this,
@@ -86,15 +74,9 @@ PluginVideosWindow::PluginVideosWindow(StackedWindow *parent) :
     connect(m_view, SIGNAL(activated(QModelIndex)), this, SLOT(showVideo(QModelIndex)));
     connect(m_view, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showContextMenu(QPoint)));
     connect(m_delegate, SIGNAL(thumbnailClicked(QModelIndex)), this, SLOT(playVideo(QModelIndex)));
-    connect(m_listAction, SIGNAL(triggered()), this, SLOT(enableListMode()));
-    connect(m_gridAction, SIGNAL(triggered()), this, SLOT(enableGridMode()));
     connect(m_reloadAction, SIGNAL(triggered()), m_model, SLOT(reload()));
     connect(m_downloadAction, SIGNAL(triggered()), this, SLOT(downloadVideo()));
     connect(m_shareAction, SIGNAL(triggered()), this, SLOT(shareVideo()));
-    
-    if (Settings::instance()->defaultViewMode() == "grid") {
-        m_gridAction->trigger();
-    }
 }
 
 PluginVideosWindow::~PluginVideosWindow() {
@@ -112,20 +94,6 @@ void PluginVideosWindow::search(const QString &service, const QString &query, co
     m_model->search(query, order);
 }
 
-void PluginVideosWindow::enableGridMode() {
-    m_delegate->setGridMode(true);
-    m_view->setFlow(QListView::LeftToRight);
-    m_view->setWrapping(true);
-    Settings::instance()->setDefaultViewMode("grid");
-}
-
-void PluginVideosWindow::enableListMode() {
-    m_delegate->setGridMode(false);
-    m_view->setFlow(QListView::TopToBottom);
-    m_view->setWrapping(false);
-    Settings::instance()->setDefaultViewMode("list");
-}
-
 void PluginVideosWindow::downloadVideo() {
     if (isBusy()) {
         return;
