@@ -39,7 +39,6 @@
 #include <QTabBar>
 #include <QStackedWidget>
 #include <QLabel>
-#include <QActionGroup>
 #include <QGridLayout>
 #include <QMessageBox>
 #include <QMenuBar>
@@ -71,9 +70,6 @@ PluginVideoWindow::PluginVideoWindow(const QString &service, const QString &id,
     m_noVideosLabel(new QLabel(QString("<p align='center'; style='font-size: 40px; color: %1'>%2</p>")
                                       .arg(palette().color(QPalette::Mid).name()).arg(tr("No videos found")), this)),
     m_noCommentsLabel(0),
-    m_viewGroup(new QActionGroup(this)),
-    m_listAction(new QAction(tr("List"), this)),
-    m_gridAction(new QAction(tr("Grid"), this)),
     m_reloadAction(new QAction(tr("Reload"), this)),
     m_downloadAction(0),
     m_shareAction(new QAction(tr("Copy URL"), this)),
@@ -113,9 +109,6 @@ PluginVideoWindow::PluginVideoWindow(const PluginVideo *video, StackedWindow *pa
     m_noVideosLabel(new QLabel(QString("<p align='center'; style='font-size: 40px; color: %1'>%2</p>")
                                       .arg(palette().color(QPalette::Mid).name()).arg(tr("No videos found")), this)),
     m_noCommentsLabel(0),
-    m_viewGroup(new QActionGroup(this)),
-    m_listAction(new QAction(tr("List"), this)),
-    m_gridAction(new QAction(tr("Grid"), this)),
     m_reloadAction(new QAction(tr("Reload"), this)),
     m_downloadAction(0),
     m_shareAction(new QAction(tr("Copy URL"), this)),
@@ -153,16 +146,10 @@ void PluginVideoWindow::loadBaseUi() {
     m_avatar->hide();
     
     m_titleLabel->setWordWrap(true);
-    m_dateLabel->setStyleSheet(QString("color: %1; font-size: 18px").arg(palette().color(QPalette::Mid).name()));
-    m_userLabel->setStyleSheet("font-size: 18px");
+    m_dateLabel->setStyleSheet(QString("color: %1; font-size: 13pt").arg(palette().color(QPalette::Mid).name()));
+    m_userLabel->setStyleSheet("font-size: 13pt");
     m_userLabel->hide();
-    
-    m_listAction->setCheckable(true);
-    m_listAction->setChecked(true);
-    m_gridAction->setCheckable(true);
-    m_viewGroup->setExclusive(true);
-    m_viewGroup->addAction(m_listAction);
-    m_viewGroup->addAction(m_gridAction);
+
     m_reloadAction->setEnabled(false);
     
     m_contextMenu->addAction(m_relatedDownloadAction);
@@ -199,8 +186,6 @@ void PluginVideoWindow::loadBaseUi() {
     m_layout->setColumnStretch(1, 1);
     m_layout->setContentsMargins(0, 0, 0, 0);
     
-    menuBar()->addAction(m_listAction);
-    menuBar()->addAction(m_gridAction);
     menuBar()->addAction(m_reloadAction);
     menuBar()->addAction(m_shareAction);
     
@@ -211,8 +196,6 @@ void PluginVideoWindow::loadBaseUi() {
     connect(m_relatedView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showContextMenu(QPoint)));
     connect(m_relatedDelegate, SIGNAL(thumbnailClicked(QModelIndex)), this, SLOT(playRelatedVideo(QModelIndex)));
     connect(m_tabBar, SIGNAL(currentChanged(int)), this, SLOT(onTabIndexChanged(int)));
-    connect(m_listAction, SIGNAL(triggered()), this, SLOT(enableListMode()));
-    connect(m_gridAction, SIGNAL(triggered()), this, SLOT(enableGridMode()));
     connect(m_reloadAction, SIGNAL(triggered()), this, SLOT(reload()));
     connect(m_thumbnail, SIGNAL(clicked()), this, SLOT(playVideo()));
     connect(m_descriptionLabel, SIGNAL(anchorClicked(QUrl)), this, SLOT(showResource(QUrl)));
@@ -225,10 +208,6 @@ void PluginVideoWindow::loadBaseUi() {
         menuBar()->insertAction(m_shareAction, m_downloadAction);
         connect(m_downloadAction, SIGNAL(triggered()), this, SLOT(downloadVideo()));
     }
-        
-    if (Settings::instance()->defaultViewMode() == "grid") {
-        m_gridAction->trigger();
-    }
 }
 
 void PluginVideoWindow::loadUserUi() {
@@ -251,20 +230,6 @@ void PluginVideoWindow::loadVideoUi() {
     }
 }
 
-void PluginVideoWindow::enableGridMode() {
-    m_relatedDelegate->setGridMode(true);
-    m_relatedView->setFlow(QListView::LeftToRight);
-    m_relatedView->setWrapping(true);
-    Settings::instance()->setDefaultViewMode("grid");
-}
-
-void PluginVideoWindow::enableListMode() {
-    m_relatedDelegate->setGridMode(false);
-    m_relatedView->setFlow(QListView::TopToBottom);
-    m_relatedView->setWrapping(false);
-    Settings::instance()->setDefaultViewMode("list");
-}
-
 void PluginVideoWindow::getRelatedVideos() {
     m_relatedModel->setService(m_video->service());
     m_relatedModel->list(m_video->id());
